<?php
/**
 * Created by PhpStorm.
 * User: MATHEUSSILVA
 * Date: 26/03/2015
 * Time: 11:17
 */

namespace Folha\Logic\ObrigacaoLegal\RAIS;

use \Folha\Entities\FpaRaismagnet;

use \Folha\Entities\FpaTpadmissao;

use \Folha\Entities\FpaTpdemissao;

use \Folha\Entities\GpeAltesalario;

use \Folha\Entities\GpeEscalatrabh;

use \Folha\Entities\GpeGrauinstr;

use \Folha\Entities\GpeNacionalidade;

use \Folha\Entities\GpeOcupacaoh;

use \Folha\Entities\GpeVinculoempreg;

use \Folha\Entities\GpeVinculom;

use \Folha\Entities\GpeVinculoh;

use \Folha\Entities\GpePessoa;

use \Folha\Entities\GpePessoah;

use \Folha\Logic\ObrigacaoLegal\RAIS\Entities\Tipo02Base;

use \Folha\Repositories\FpaCalculofolha;

use \Folha\Repositories\FpaIncidevento;

use \Folha\Repositories\Gpealtesitufunc;

use \Geral\Entities\Enderecoparc;

use \Geral\Entities\Estruturah;

use \Geral\Util\Ambiente;

use \HCM\Util\DateUtil;

use \Geral\Util\NovoCodigo;



class Tipo02 extends Tipo02Base
{

    private $ano;
    /** @var  $pessoa GpePessoa */
    private $pessoa;
    /** @var  $pessoah GpePessoah */
    private $pessoah;
    /** @var  $vinculom GpeVinculom */
    private $vinculom;
    /** @var  $vinculoh GpeVinculoh */
    private $vinculoh;
    /** @var  int $nrformrais */
    private $nrformrais;


    /**
     * Construtor
     * @param GpeVinculom $vinculom
     * @param GpeVinculoh $vinculoh
     * @param int $ano
     * @param int $cnpj
     * @param int $grupoIncidencia
     * @throws \Exception
     */
    function __construct( $vinculom, $vinculoh, $ano, $cnpj, $grupoIncidencia, $nrformrais)
    {
        $this->ano = $ano;
        $this->setDefault($cnpj);
        $this->setBasicInfo( $vinculom, $vinculoh);
        $this->setPersonInfo();
        $this->setProfissInfo($grupoIncidencia);
        $this->setAfastInfo();
        $this->nrformrais = $nrformrais;

    }

    /**
     * Seta os valores padrões
     * @param int $cnpj
     * @return bool
     */
    private function setDefault($cnpj)
    {
        $this->tipoRegistro = '2';
        $this->prefixo = '00';
        $this->alvara = 2;
        $this->bancoDados = null;
        $this->quantMeses = null;
        $this->filiadoSindicato = '2';
        $this->infoEmpresa = null;
        $this->cnpj = $cnpj;
        $this->cnpjConAssocPri = null;
        $this->valorConAssoPri = null;
        $this->cnpjConAssocSeg = null;
        $this->valorConAssoSeg = null;
        $this->cnpjConSindiSeg = null;
        $this->valorConSindSeg = null;
        $this->cnpjConAssisSeg = null;
        $this->valorConAssiSeg = null;
        $this->cnpjConConfeSeg = null;
        $this->valorConConfSeg = null;

        return true;
    }

    /**
     * Seta as informações básicas da RAIS
     * @param GpeVinculom $vinculom
     * @param GpeVinculoh $vinculoh
     * @throws \Exception
     */
    private function setBasicInfo( $vinculom, $vinculoh)
    {
        try {
            //BUSCA DADOS DA PESSOA
            $where = 'NRORG = :P_NRORG AND NRPESSOA = :P_NRPESSOA';
            $params = array(
                'P_NRORG' => $vinculom->getNrorg(),
                'P_NRPESSOA' => $vinculom->getNrpessoa()
            );
            $orderBy = '';
            $pessoa = GpePessoa::getObjectByWhere($where, $params, $orderBy);
            /** @var GpePessoa $pessoa */

            if(!$pessoa){
                $params = array(
                    $vinculom->getNrvinculom(),
                    $vinculom->getNmvinculom()
                );
                throw Exception::newException(Exception::ERRO_VINCULO_SEM_PESSOA, $params);
            }

            //BUSCA DADOS DO HISTORICO DA PESSOA
            $where = 'NRORG = :P_NRORG AND NRPESSOA = :P_NRPESSOA AND DTMESCOMPETENC <= :P_DTMESCOMPETENC';
            $params = array(
                'P_NRORG' => $vinculom->getNrorg(),
                ':P_NRPESSOA' => $vinculom->getNrpessoa(),
                'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
            );
            $orderBy = 'DTMESCOMPETENC DESC';
            $pessoah = GpePessoah::getObjectByWhere($where, $params, $orderBy);
            /** @var GpePessoah $pessoah */

            if(!$pessoah){
                $params = array(
                    $pessoa->getNrpessoa(),
                    $vinculom->getNmvinculom()
                );
                throw Exception::newException(Exception::ERRO_PESSOA_SEM_HISTORICO, $params);
            }

            $this->pessoa = $pessoa;
            $this->pessoah = $pessoah;
            $this->vinculom = $vinculom;
            $this->vinculoh = $vinculoh;

            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Seta as informações pessoais do vínculo
     * @return boolean
     * @throws \Exception
     */
    private function setPersonInfo()
    {

        try {
            //BUSCA DADOS DA NACIONALIDADE DA PESSOA
            $where = 'NRNACIONALIDADE = :P_NRNACIONALIDADE';
            $params = array(
                'P_NRNACIONALIDADE' => $this->pessoah->getNacionalid(),
            );
            $orderBy = '';
            $nacionalidade = GpeNacionalidade::getObjectByWhere($where, $params, $orderBy);
            /** @var GpeNacionalidade $nacionalidade */


            //BUSCA DADOS DO GRAU DE INSTRUÇÃO DA PESSOA
            $where = 'NRGRAUINSTR = :P_NRGRAUINSTR';
            $params = array(
                'P_NRGRAUINSTR' => $this->pessoah->getGrauinstr(),
            );
            $orderBy = '';
            $ginstrucao = GpeGrauinstr::getObjectByWhere($where, $params, $orderBy);
            /** @var GpeGrauinstr $ginstrucao */


            //Seta as informações básicas
            $this->codigoPisPasep = $this->pessoah->getNrpispaseppes();
            $this->nomeEmpregado = $this->pessoah->getNmpessoa();
            $this->dataNascimento = $this->pessoah->getDtnascpessoa();
            $this->anoChegPais = $this->pessoah->getNranochegapais();
            $this->cpf = $this->pessoah->getNrcpfpessoa();

            if($nacionalidade){
                $this->nacionalidade = $nacionalidade->getCdrais();
            }else{
                $params = array(
                    $this->pessoah->getNrpessoa(),
                    $this->pessoah->getNmpessoa()
                );
                Exception::newException(Exception::ALERTA_NACIONALID_INEXIST, $params, Exception::EXCEPTION_ALERTA);
            }

            if($ginstrucao instanceof GpeGrauinstr){
                $this->grauInstrucao = $ginstrucao->getCodrais();
            }else{
                    $params = array(
                        $this->pessoah->getNrpessoa(),
                        $this->pessoah->getNmpessoa()
                    );
                    Exception::newException(Exception::ALERTA_GRAU_INSTR_INEXIST, $params, Exception::EXCEPTION_ALERTA);
                }

            if ($this->pessoah->getIdsexopessoa() == 'M') {
                $this->sexo = '1';
            } else {
                $this->sexo = '2';
            }

            switch ($this->pessoah->getNrracapessoa()) {
                case(1): {
                    $this->raca = 1;
                    break;
                }
                case(2): {
                    $this->raca = 2;
                    break;
                }
                case(3): {
                    $this->raca = 4;
                    break;
                }
                case(4): {
                    $this->raca = 6;
                    break;
                }
                case(5): {
                    $this->raca = 8;
                    break;
                }
                default: {
                $this->raca = 9;
                break;
                }
            }

            switch ($this->pessoah->getNrcondfispes()) {
                case(1): {
                    $this->deficiencia = 2;
                    $this->tipoDeficiencia = 0;
                    break;
                }
                case(2): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 1;
                    break;
                }
                case(3): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 2;
                    break;
                }
                case(4): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 3;
                    break;
                }
                case(5): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 4;
                    break;
                }
                case(6): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 5;
                    break;
                }
                case(7): {
                    $this->deficiencia = 1;
                    $this->tipoDeficiencia = 6;
                    break;
                }
            }

            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Seta as informações profissionais do vínculo
     * @param int $grupoIncidencia
     * @throws \Exception
     */
    private function setProfissInfo($grupoIncidencia)
    {

        try {
            //BUSCA DADOS DA ESCALA DE TRABALHO DO VÍNCULO
            $where = "NRORG = :P_NRORG AND NRESCALATRABM = :P_NRESCALATRABM AND DTMESCOMPETENC <= :P_DTMESCOMPETENC";
            $params = array(
                'P_NRORG' => $this->vinculoh->getNrorg(),
                'P_NRESCALATRABM' => $this->vinculoh->getNrescalatrabm(),
                'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
            );
            $orderBy = 'DTMESCOMPETENC DESC';
            $escalaTrabalho = GpeEscalatrabh::getObjectByWhere($where, $params, $orderBy);
            /** @var GpeEscalatrabh $escalaTrabalho */

            if(!$escalaTrabalho){
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                throw Exception::newException(Exception::ERRO_ESCALATRAB_VINCULO, $params);
            }

            //BUSCA DADOS DA OCUPAÇÃO DO VÍNCULO
            $where = "NRORG = :P_NRORG AND NROCUPACAOM = :P_NROCUPACAOM AND DTMESCOMPETENC <= :P_DTMESCOMPETENC";
            $params = array(
                'P_NRORG' => $this->vinculoh->getNrorg(),
                'P_NROCUPACAOM' => $this->vinculoh->getNrCargo(),
                'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
            );
            $orderBy = 'DTMESCOMPETENC DESC';
            $ocupacao = GpeOcupacaoh::getObjectByWhere($where, $params, $orderBy);
            /** @var GpeOcupacaoh $ocupacao */

            if(!$ocupacao){
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                throw Exception::newException(Exception::ERRO_OCUPACAO_VINCULO, $params);
            }

            //BUSCA DADOS DA ESTRUTURA ONDE O VÍNCULO ESTÁ ALOCADO
            $where = "NRORG = :P_NRORG AND NRESTRUTURAM = :P_NRESTRUTURAM AND DTMESCOMPETENC <= :P_DTMESCOMPETENC";
            $params = array(
                'P_NRORG' => $this->vinculoh->getNrorg(),
                'P_NRESTRUTURAM' => $this->vinculoh->getNrestrutgeren(),
                'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
            );
            $orderBy = "DTMESCOMPETENC DESC";
            $estruturaTrabalho = Estruturah::getObjectByWhere($where, $params, $orderBy);
            /** @var Estruturah $estruturaTrabalho */

            if(!$estruturaTrabalho){
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                throw Exception::newException(Exception::ERRO_GERENCIAL_VINCULO, $params);
            }

            //BUSCA ENDEREÇO DA ESTRUTURA ONDE O VÍNCULO ESTÁ ALOCADO
            $where = "NRORG = :P_NRORG AND NRPARCNEGOCIO = :P_NRPARCNEGOCIO";
            $params = array(
                'P_NRORG' => $this->vinculoh->getNrorg(),
                'P_NRPARCNEGOCIO' => $estruturaTrabalho->getNrparcnegocio(),
                'P_DTMESCOMPETENC' => "31/12/{$this->ano}"
            );
            $orderBy = "";
            $enderecoEmpresa = Enderecoparc::getObjectByWhere($where, $params, $orderBy);
            /** @var Enderecoparc $enderecoEmpresa */ //


            if ($this->vinculom->getTpadmissao() instanceof FpaTpadmissao) {
                $this->tipoAdmissao = $this->vinculom->getTpadmissao()->getCodrais();
            }
            $this->dataAdmissao = $this->vinculom->getDtadmissaovinc();
            $this->dataDesligamento = $this->vinculom->getDtrescisaovinc();
            $this->avisoPrevio = $this->vinculom->getDtavisoprevio();
            $this->ctpsNumero = $this->pessoah->getNrctpspessoa();
            $this->ctpsSerie = $this->pessoah->getNrseriectpspes();
            $this->horasSemanais = $escalaTrabalho->getQthrsemesctrabh();

            if (!is_null($ocupacao->getCbo())) {
                $this->cbo = $ocupacao->getCbo()->getCdrais();
            }else{
                $params = array($ocupacao->getNrocupacaom());
                Exception::newException(Exception::ALERTA_OCUPACAO_SEM_CBO, $params, Exception::EXCEPTION_ALERTA);
            }

            if ($this->vinculom->getVinculoempreg() instanceof GpeVinculoempreg) {
                $this->vinculoEmpregat = $this->vinculom->getVinculoempreg()->getCodrais();
            }else{
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                throw Exception::newException(Exception::ERRO_VINCULO_VINCULOEMPR, $params);
            }


            if($this->vinculom->getTpdemissao() instanceof FpaTpdemissao){
                $this->codDesligamento = $this->vinculom->getTpdemissao()->getCodrais();
            }elseif(!is_null($this->vinculom->getDtrescisaovinc())){
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                Exception::newException(Exception::ERRO_TPDEMISSAO_VINCULO, $params);
            }


            if(!is_null($enderecoEmpresa->getCdmunicipio())){
                $this->municipioTrabalho = $enderecoEmpresa->getMunicipio()->getCdmunicibge();
            }else{
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                Exception::newException(Exception::ERRO_GERENCIAL_ENDERECO, $params);
            }

            $this->setPaymInfo($grupoIncidencia);

            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     * Seta as informações de pagamentos
     * @param int $grupoIncidencia
     * @throws \Exception
     */
    private function setPaymInfo($grupoIncidencia)
    {
        try {
            $inicio = "01/01/{$this->ano}";
            $final = "31/12/{$this->ano}";


            //BUSCA DADOS DE REMUNERAÇÃO DO VÍNCULO
            $where = 'NRORG = :P_NRORG AND NRVINCULOM = :P_NRVINCULOM';
            $params = array(
                'P_NRORG' => $this->vinculom->getNrorg(),
                'P_NRVINCULOM' => $this->vinculom->getNrvinculom()
            );
            $orderBy = '';
            $remuneracao = GpeAltesalario::getObjectByWhere($where, $params, $orderBy);
            /** @var GpeAltesalario $remuneracao */ //

            if (!$remuneracao) {
                $params = array(
                    $this->vinculom->getNrvinculom(),
                    $this->vinculom->getNmvinculom(),
                );
                Exception::newException(Exception::ERRO_ALTSALARIAL_VINCULO, $params);
            }


            $salario = FpaIncidevento::getSalarioRais($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, $grupoIncidencia);

            $dterc_adiantamento = FpaCalculofolha::getDecimoTerceiro($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, self::DEC_TERCEIRO_ADIANTAMENTO);
            $dterc_final = FpaCalculofolha::getDecimoTerceiro($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, self::DEC_TERCEIRO_FINAL);

            $feriasIndenizadas = FpaCalculofolha::getFeriasIndenizada($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, self::FERIAS_INDENIZADAS_EVENTOS, self::FERIAS_INDENIZADAS_MOVIMENTOS);

            $gratificacoes = Fpacalculofolha::getGratificacoes($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, self::GRATIFICACOES_EVENTOS, self::GRATIFICACOES_MOVIMENTOS);

            $dissidio = Fpacalculofolha::getDissidio($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final);

            $multaRecisao = FpaCalculofolha::getDecimoTerceiro($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, self::MULTA_RECISAO);

            $hrExtras = FpaCalculofolha::getHorasExtrasRais($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $inicio, $final, $grupoIncidencia);

            $this->salarioContratu = $remuneracao->getVrsalario();
            $this->tipoSalContratu = $remuneracao->getTpmodalidsal();

            $this->remunJaneiro = $salario['JANEIRO']*100;
            $this->remunFevereiro = $salario['FEVEREIRO']*100;
            $this->remunMarco = $salario['MARCO']*100;
            $this->remunAbril = $salario['ABRIL']*100;
            $this->remunMaio = $salario['MAIO']*100;
            $this->remunJunho = $salario['JUNHO']*100;
            $this->remunJulho = $salario['JULHO']*100;
            $this->remunAgosto = $salario['AGOSTO']*100;
            $this->remunSetembro = $salario['SETEMBRO']*100;
            $this->remunOutubro = $salario['OUTUBRO']*100;
            $this->remunNovembro = $salario['NOVEMBRO']*100;
            $this->remunDezembro = $salario['DEZEMBRO']*100;

            $this->remun13Adianta = $dterc_adiantamento['VALOR_TOTAL']*100;
            $this->mes13Adianta = $dterc_adiantamento['DTOCORRENCIA'];
            $this->remun13Final = $dterc_final['VALOR_TOTAL']*100;
            $this->mes13Final = $dterc_final['DTOCORRENCIA'];

            $this->feriasIndenizada = $feriasIndenizadas['VALOR']*100;

            $this->gratificacoes = $gratificacoes[0]['VREVENTOFOLHA']*100;
            $this->mesesGratifica = $gratificacoes[0]['QUANT_MESES'];

            $this->valorDissidio = $dissidio[0]['VRDIFEREALTE']*100;
            $this->quantMesesDissid = $dissidio[0]['QUANTMESES'];

            $this->multRescSemJust = $multaRecisao['VALOR_TOTAL']*100;

            $this->horaExtraJaneiro = \Valor::arredonda($hrExtras['JANEIRO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtFevereiro = \Valor::arredonda($hrExtras['FEVEREIRO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraMarco = \Valor::arredonda($hrExtras['MARCO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraAbril = \Valor::arredonda($hrExtras['ABRIL']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraMaio = \Valor::arredonda($hrExtras['MAIO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraJunho = \Valor::arredonda($hrExtras['JUNHO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraJulho = \Valor::arredonda($hrExtras['JULHO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtraAgosto = \Valor::arredonda($hrExtras['AGOSTO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtrSetembro = \Valor::arredonda($hrExtras['SETEMBRO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtrOutubro = \Valor::arredonda($hrExtras['OUTUBRO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtrNovembro = \Valor::arredonda($hrExtras['NOVEMBRO']*100, \Valor::TOTAL, 0, 5);
            $this->horaExtrDezembro = \Valor::arredonda($hrExtras['DEZEMBRO']*100, \Valor::TOTAL, 0, 5);

            switch($remuneracao->getIdtpsalario()){
                case(self::MOD_SALARIO_MENSAL):{
                    $this->tipoSalContratu = 1;
                    break;
                }
                case(self::MOD_SALARIO_QUINZENAL):{
                    $this->tipoSalContratu = 2;
                    break;
                }
                case(self::MOD_SALARIO_SEMANAL):{
                    $this->tipoSalContratu = 3;
                    break;
                }
                case(self::MOD_SALARIO_DIARIO):{
                    $this->tipoSalContratu = 4;
                    break;
                }
                case(self::MOD_SALARIO_HORA):{
                    $this->tipoSalContratu = 5;
                    break;
                }
                case(self::MOD_SALARIO_TAREFA):{
                    $this->tipoSalContratu = 6;
                    break;
                }
                default:{
                    $this->tipoSalContratu = 7;
                    break;
                }
            }

            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    /**
     *
     * @return bool
     * @throws \Exception
     */
    private function setAfastInfo()
    {
        try {
            $dataInicio = "01/01/$this->ano";
            $dataFinal = "31/12/$this->ano";
            $info = Gpealtesitufunc::getAfastamento($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $dataInicio, $dataFinal);
            $diasAfastamento = GpeAltesitufunc::getTotalAfastamento($this->vinculom->getNrvinculom(), $this->vinculom->getNrorg(), $dataInicio, $dataFinal);

            if((!$info)&&(isset($info[0]['DTINISITUFUNC']))){
                $dataIniPriAfast = DateUtil::getDataDeString($info[0]['DTINISITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);
                $dataFimPriAfast = DateUtil::getDataDeString($info[0]['DTFIMSITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);

                $this->motPriAfastam = $info[0]['CODRAIS'];
                $this->dataIniPriAfast = $dataIniPriAfast->format('d/m');
                $this->dataFimPriAfast = $dataFimPriAfast->format('d/m');
            }

            if((!$info)&&(isset($info[1]['DTINISITUFUNC']))){
                $dataIniSegAfast = DateUtil::getDataDeString($info[1]['DTINISITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);
                $dataFimSegAfast = DateUtil::getDataDeString($info[1]['DTFIMSITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);

                $this->motSegAfastam = $info[1]['CODRAIS'];
                $this->dataIniSegAfast = $dataIniSegAfast->format('d/m');
                $this->dataFimSegAfast = $dataFimSegAfast->format('d/m');
            }

            if((!$info)&&(isset($info[2]['DTINISITUFUNC']))){
                $dataIniTerAfast = DateUtil::getDataDeString($info[2]['DTINISITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);
                $dataFimTerAfast = DateUtil::getDataDeString($info[2]['DTFIMSITUFUNC'], DateUtil::FORMATO_BRASILEIRO, true);

                $this->motTerAfastam = $info[2]['CODRAIS'];
                $this->dataIniTerAfast = $dataIniTerAfast->format('d/m');
                $this->dataFimTerAfast = $dataFimTerAfast->format('d/m');
            }


            if((!$diasAfastamento)&&(isset($diasAfastamento[0]['TEMPO']))){
                $this->quantDias = $diasAfastamento[0]['TEMPO'];
            }

            return true;
        } catch (\Exception $e) {
            throw $e;
        }

    }

    /**
     * Inserir o magnético no Banco de Dados.
     *
     * @param $linha
     * @param $cnpj
     * @param $admissao
     * @param $tipoInsc
     * @param $vinculo
     * @param $pis
     */
    private function salvarMagnetico($linha, $cnpj, $admissao, $tipoInsc, $vinculo, $pis)
    {
        $competencia = \FPA::getDtCompetencia();

        //TRATA A DATA DE ADMISSÃO
        if(!($admissao instanceof \DateTime)){
            $admissao = DateUtil::getDataDeString($admissao);
        }

        //TRATA A DATA DE COMPETENCIA
        if(!($competencia instanceof \DateTime)){
            $competencia = DateUtil::getDataDeString($competencia);
        }

        //CRIA UM OBJETO A SER SALVO NO BANCO
        $mag = new FpaRaismagnet();
        $mag->setNrraismagnet(NovoCodigo::geraCodigo(Ambiente::getNrorgTrabalho(), 'FPA_RAISMAGNET', 1, 22, true));
        $mag->setMescompetencia($competencia);
        $mag->setDslinharegistro($linha . '*');
        $mag->setCdinscestrut($cnpj);
        $mag->setDtadmissaovinc($admissao);
        $mag->setIdtpinscestrutu($tipoInsc);
        $mag->setNrvinculom($vinculo);
        $mag->setNrpispaseppes($pis);
        $mag->setNrorg(Ambiente::getNrorgTrabalho());
        $mag->setIdativo('S');
        $mag->setIdtiporegistro($this->nrformrais);
        $mag->setDtinclusao(DateUtil::getDataAtual());

        //SALVA UM OBJETO A SER COMITADO NO BANCO
        $mag->persist();
    }

} 